Package: Rwave
Version: 2.6-5
Date: 2022-10-18
Title: Time-Frequency Analysis of 1-D Signals
Authors@R: c(person(given="Rene", family='Carmona', email='rcarmona@princeton.edu', role='aut'),
	   person(given="Bruno", family='Torresani', email='bruno.torresani@cmi.univ-mrs.fr', role='aut'),
	   person(given="Brandon", family='Whitcher', email='bjw34032@users.sourceforge.net', role='ctb'),
	   person(given="Andrea", family='Wang', role='ctb'),
	   person(given="Wen-Liang", family='Hwang', role='ctb'),
	   person(given="Robert", family="Alberts", role='ctb'),
	   person(given="Jonathan M.", family="Lees", role = c("ctb", "cre"), email = "jonathan.lees@unc.edu"))
Author: Rene Carmona [aut],
  Bruno Torresani [aut],
  Brandon Whitcher [ctb],
  Andrea Wang [ctb],
  Wen-Liang Hwang [ctb],
  Robert Alberts [ctb],
  Jonathan M. Lees [ctb, cre]
Maintainer: Jonathan M. Lees <jonathan.lees@unc.edu>
Depends: R (>= 2.14)
Description: A set of R functions which provide an
        environment for the Time-Frequency analysis of 1-D signals (and
        especially for the wavelet and Gabor transforms of noisy
        signals). It was originally written for Splus by Rene Carmona,
        Bruno Torresani, and Wen L. Hwang, first at the University of
        California at Irvine and then at Princeton University.  Credit
        should also be given to Andrea Wang whose functions on the
        dyadic wavelet transform are included. Rwave is based on the
        book: "Practical Time-Frequency Analysis: Gabor and Wavelet
        Transforms with an Implementation in S", by Rene Carmona, Wen
        L. Hwang and Bruno Torresani (1998, eBook ISBN:978008053942), Academic Press.
License: GPL (>= 2)
Copyright: University of California
URL: https://carmona.princeton.edu/TFbook/tfbook.html,
        https://r-forge.r-project.org/projects/rwave/
Packaged: 2022-10-20 16:53:19 UTC; lees
Repository: CRAN
Date/Publication: 2022-10-21 23:17:49 UTC
NeedsCompilation: yes
Built: R 4.6.0; aarch64-apple-darwin23; 2026-04-25 21:06:59 UTC; unix
Archs: Rwave.so.dSYM
