\name{npl}
\alias{npl}
\title{
Prepare Graphics Environment
}
\description{
Splits the graphics device into prescrivbed number of windows.
}
\usage{
npl(nbrow)
}
\arguments{
\item{nbrow}{
number of plots.
}}
%\value{}
%\details{}
%\references{}
%\seealso{}
\keyword{ts}
