\name{sig_W_tilda.1}
\alias{sig_W_tilda.1}
\title{Pixel from Amber Camara}
\description{Pixel from amber camara.
}
\usage{data(sig_W_tilda.1)
}
\format{A vector containing observations.
}
\source{
  See discussions in the text of ``Practical Time-Frequency Analysis''.
}
\references{
  Carmona, R. A., W. L. Hwang and B Torresani (1998, eBook ISBN:978008053942)
  \emph{Practical Time-Frequency Analysis: Gabor and Wavelet Transforms
    with an Implementation in S}, Academic Press, San Diego.
}
\examples{

data(sig_W_tilda.1)
plot.ts(sig_W_tilda.1)

}

\keyword{datasets}
